@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.868';
+our $VERSION = '1.874';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -697,7 +697,7 @@ MCE::Step - Parallel step model for building creative steps
 
 =head1 VERSION
 
-This document describes MCE::Step version 1.868
+This document describes MCE::Step version 1.874
 
 =head1 DESCRIPTION
 
@@ -878,9 +878,9 @@ inside the first block. Hence, the block is called once per each item.
  ## Exports mce_step, mce_step_f, and mce_step_s
  use MCE::Step;
 
- MCE::Step::init {
+ MCE::Step->init(
     chunk_size => 1
- };
+ );
 
  ## Array or array_ref
  mce_step sub { do_work($_) }, 1..10000;
@@ -914,9 +914,9 @@ This means having to loop through the chunk from inside the first block.
 
  use MCE::Step;
 
- MCE::Step::init {          ## Chunk_size defaults to 'auto' when
+ MCE::Step->init(           ## Chunk_size defaults to 'auto' when
     chunk_size => 'auto'    ## not specified. Therefore, the init
- };                         ## function may be omitted.
+ );                         ## function may be omitted.
 
  ## Syntax is shown for mce_step for demonstration purposes.
  ## Looping inside the block is the same for mce_step_f and
@@ -983,7 +983,7 @@ both gather and bounds_only options may be specified when calling init
 
  use MCE::Step;
 
- MCE::Step::init {
+ MCE::Step->init(
     chunk_size => 1, max_workers => 4,
 
     user_begin => sub {
@@ -993,7 +993,7 @@ both gather and bounds_only options may be specified when calling init
     user_end => sub {
        print "## ", MCE->wid, " completed\n";
     }
- };
+ );
 
  my %a = mce_step sub { MCE->gather($_, $_ * $_) }, 1..100;
 
@@ -1019,7 +1019,7 @@ both gather and bounds_only options may be specified when calling init
  7569 7744 7921 8100 8281 8464 8649 8836 9025 9216 9409 9604 9801
  10000
 
-Like with MCE::Step::init above, MCE options may be specified using an
+Like with MCE::Step->init above, MCE options may be specified using an
 anonymous hash for the first argument. Notice how task_name, max_workers,
 and use_threads can take an anonymous array for setting uniquely per
 each code block.
@@ -1148,10 +1148,10 @@ needed after the block.
 
  # Here, options are specified via init
 
- MCE::Step::init {
+ MCE::Step->init(
     max_workers => [  1,   3  ],
     task_name   => [ 'p', 'c' ]
- };
+ );
 
  mce_step \&producer, \&consumers;
 
@@ -1236,10 +1236,10 @@ Time was measured using 1 worker to emphasize the difference.
 
  use MCE::Step;
 
- MCE::Step::init {
+ MCE::Step->init(
     max_workers => 1, chunk_size => 1_250_000,
     bounds_only => 1
- };
+ );
 
  # Typically, the input scalar $_ contains the sequence number
  # when chunk_size => 1, unless the bounds_only option is set
@@ -1282,14 +1282,14 @@ Time was measured using 1 worker to emphasize the difference.
 =back
 
 An iterator reference may be specified for input_data. The only other way
-is to specify input_data via MCE::Step::init. This prevents MCE::Step from
+is to specify input_data via MCE::Step->init. This prevents MCE::Step from
 configuring the iterator reference as another user task which will not work.
 
 Iterators are described under section "SYNTAX for INPUT_DATA" at L<MCE::Core>.
 
- MCE::Step::init {
+ MCE::Step->init(
     input_data => iterator
- };
+ );
 
  mce_step sub { $_ };
 
@@ -1317,10 +1317,10 @@ sub-task.
     MCE->printf( "%d: %d, %03.06f\n", MCE->wid, $args[0], $args[1] );
  }
 
- MCE::Step::init {
+ MCE::Step->init(
     task_name   => [ 'p', 'c' ],
     max_workers => [  1 ,  4  ]
- };
+ );
 
  mce_step \&provider, \&consumer;
 
@@ -1381,10 +1381,10 @@ will cause an error.
     MCE->printf( "D%d: %d, %03.06f\n", MCE->wid, $args->[0], $args->[1] );
  }
 
- MCE::Step::init {
+ MCE::Step->init(
     task_name   => [ 'p', 'c', 'd' ],
     max_workers => [  2 ,  3 ,  3  ]
- };
+ );
 
  mce_step \&provider, \&consumer_c, \&consumer_d;
 
@@ -1440,10 +1440,10 @@ items pending in its queue.
     sleep 0.05;
  }
 
- MCE::Step::init {
+ MCE::Step->init(
     task_name   => [ 'p', 'c' ],
     max_workers => [  1 ,  4  ]
- };
+ );
 
  mce_step \&provider, \&consumer;
 
@@ -1586,9 +1586,9 @@ gathering data such as retaining output order.
  ## the case and depends on Perl. Pass a reference to a subroutine if
  ## workers must persist; e.g. mce_step { ... }, \&foo, 1..100000.
 
- MCE::Step::init {
+ MCE::Step->init(
     chunk_size => 'auto', max_workers => 'auto'
- };
+ );
 
  for (1..2) {
     my @m2;
@@ -1611,7 +1611,7 @@ gathering data such as retaining output order.
     print scalar @m2, "\n";
  }
 
- MCE::Step::finish;
+ MCE::Step->finish;
 
 All 6 models support 'auto' for chunk_size unlike the Core API. Think of the
 models as the basis for providing JIT for MCE. They create the instance, tune
@@ -1667,13 +1667,13 @@ longer needed.
 
  use MCE::Step;
 
- MCE::Step::init {
+ MCE::Step->init(
     chunk_size => 20, max_workers => 'auto'
- };
+ );
 
  mce_step sub { ... }, 1..100;
 
- MCE::Step::finish;
+ MCE::Step->finish;
 
 =head1 INDEX
 
